@@ -1,7 +1,7 @@
 #!/bin/bash
 # Drupal	(http://drupal.org)
 #	BuildScript for Plamo Linux 4.7
-#			by Jun Kuwamura <juk@linet.gr.jp> on 2010-03-11
+#			by Jun Kuwamura <juk@linet.gr.jp> on 2010-08-28
 # require:
 #	httpd-2.2.x
 #	php-5.2.x
@@ -15,7 +15,7 @@ tar xfz drush-All-Versions-HEAD.tar.gz
 export PATH=/opt/php5/bin:$PATH
 
 ./drush/drush dl drupal > drush-dl-drupal.log
-VERSION=`sed -e s'/.*(\(.*\)).*/\1/' drush-dl-drupal.log`
+VERSION=`head -1 drush-dl-drupal.log | sed -e s'/.*(\(.*\)).*/\1/'`
 PAC_NAME=drupal-$VERSION
 (cd $PAC_NAME; ../drush/drush dl ja > drush-dl-ja.log)
 JVERS=`sed -e s'/.*(\(.*\)).*/\1/' drush-dl-ja.log`
@@ -34,9 +34,9 @@ PAC_DIR=$PLAMO/Packages/4.7/09_webdb/03_PHP.tgz
 BUILD_DIR=$PLAMO/drupal6
 CUSTOM_DIR=$BUILD_DIR/Custom
 
-( cd $CUSTOM_DIR; 
-  wget -N http://drupal.org/files/issues/search-chouonpu-D6.patch )
-PAT_FILE=search-chouonpu-D6.patch
+#( cd $CUSTOM_DIR; 
+#  wget -N http://drupal.org/files/issues/search-chouonpu-D6.patch )
+#PAT_FILE=search-chouonpu-D6.patch
 
 REL=P1
 CPU=noarch
